%define momorel 1

# define target service directory: %{djbdir}/service: 0     /service: 1
%define rootsrv 0

# commandline overrides:
# rpm -ba|--rebuild --with 'xxx'
%{?rootservice: %{expand: %%define rootsrv 1}}

# created by Vincent Danen <vdanen@mandrakesoft.com>
# http://www.mandrakesecure.net/en/docs/djbdns.php

%define djbdir	/var/djbdns

%if %{rootsrv}
  %define service /service
%else
  %define service %{djbdir}/service
%endif


Name:		djbdns
Summary:	djbdns DNS server
Version:	1.05
Release:	%{momorel}m
License:	D. J. Bernstein
Group:		System Environment/Daemons
URL:		http://cr.yp.to/djbdns.html
Source0:	http://cr.yp.to/djbdns/%{name}-%{version}.tar.gz
Source1:	doc.tar.bz2
Source2:	%{name}.init
Source3:	%{name}-getdata
Source4:	ftp://ftp.innominate.org/gpa/djb/%{name}-%{version}-man.tar.bz2
Source5:	%{name}.cron
Source6:	tinydns-log.pl
Patch0:		djbdns-1.05-errno.patch.bz2
Requires:	chkconfig, initscripts, sh-utils, daemontools, ucspi-tcp
Buildprereq:	shadow-utils
Buildroot:	%{_tmppath}/%{name}-%{version}-root
Conflicts:	bind, caching-nameserver, %{name}-extcache

NoSource: 0


%description
djbdns is a collection of Domain Name System tools.  It includes several
components:

 * The dnscache program is a local DNS cache.  It accepts recursive DNS
   queries from local clients such as web browsers.  It collects responses
   from remote DNS servers.
 * The tinydns program is a fast, UDP-only DNS server.  It makes local DNS
   information available to the Internet.  It supports load balancing and
   client differentation.
 * The walldns program is a reverse DNS wall.  It provides matching reverse
   and forward records while hiding local host information.
 * The rbldns program is an IP-address-listing DNS server.  It uses DNS to
   publish a list of IP addresses, such as RBL or DUL.
 * The dns library handles outgoing and incoming DNS packets.  It can be
   used by clients such as web browsers to look up host addresses, hot names,
   MX records, etc.  It supports asynchronous resolution.
 * The dnsfilter program is a parallel IP-address-to-host-name converter.
 * The dnsip, dnsipq, dnsname, dnstxt, and dnsmx programs are simple
   command-line interfaces to DNS.
 * The dnsq and dnstrace programs are DNS debugging tools.

If you wish to replicate DNS information to secondary djbdns servers, you will
also need to install openssh and rsync to perform the actual replication.
This is not required unless you want to replicate to a secondary djbdns server
and is not required if your secondary is a BIND DNS server.



%package extcache
Summary:	djbdns for caching only dns servers
Group:		System Environment/Daemons
Requires:	chkconfig, initscripts, sh-utils, daemontools, ucspi-tcp
Conflicts:	%{name}, caching-nameserver, bind, %{name}-localcache
Obsoletes:	%{name}-cache

%description extcache
This package provides djbdns caching and should only be used if you want a
caching nameserver that can be accessed by other hosts.  If you want to run a 
full DNS server, install the djbdns package instead of this one.  If you
want a local-only caching nameserver, install djbdns-localcache.  This
package includes the following components:

 * The dnscache program is a local DNS cache.  It accepts recursive DNS
   queries from local clients such as web browsers.  It collects responses
   from remote DNS servers.
 * The dnsip, dnsipq, dnsname, dnstxt, and dnsmx programs are simple
   command-line interfaces to DNS.



%package localcache
Summary:	djbdns for caching only dns servers
Group:		System Environment/Daemons
Requires:	chkconfig, initscripts, sh-utils, daemontools, ucspi-tcp
Conflicts:	caching-nameserver, bind, %{name}-extcache
Obsoletes:	%{name}-cache

%description localcache
This package provides djbdns caching and should only be used if you want a
caching nameserver that can only be accessed by localhost.  If you want to 
run a full DNS server also, install the djbdns package as well.  If you
want a caching nameserver that can be accessed by other hosts, install 
djbdns-extcache.  This package includes the following components:

 * The dnscache program is a local DNS cache.  It accepts recursive DNS
   queries from local clients such as web browsers.  It collects responses
   from remote DNS servers.
 * The dnsip, dnsipq, dnsname, dnstxt, and dnsmx programs are simple
   command-line interfaces to DNS.



%package devel
Summary:	Development files for djbdns
Group:		System Environment/Daemons
Requires:	%{name}

%description devel
These are header and library files for djbdns to be used in third-party 
programs.


%prep
%setup -q
# docs
# manpages
%setup -q -T -D -c -a 4 -n %{name}-%{version}
%setup -q -T -D -c -a 1 -n %{name}-%{version}

%patch0 -p1 -b .errno

# make README.RPM:

COMPILER="Compiler:               $(gcc -v 2>& 1|tail -1)"
HARDWARE="Hardware platform:      $(uname -m)"
LIBRARY="Library:                $(rpm -q glibc)"
OSVERSION="Linux Kernel:           $(uname -sr)"
MORELEASE="Momonga-Linux release: $(cat /etc/momonga-release)"
RPMVERSION="RPM Version:            $(rpm -q rpm)"
RPMOPTIONS="Package build options: "

RPMOPTIONS="$RPMOPTIONS service=%{service}"


cat <<EOF >>$RPM_BUILD_DIR/%{name}-%{version}/README.RPM
The djbdns rpm packages were created in the following build environment:

$MORELEASE
$HARDWARE
$OSVERSION
$LIBRARY
$COMPILER
$RPMVERSION
$RPMOPTIONS

Ever effort has been made to ensure that the package behaves correctly and
as the author intended.  While some path relocation exists
(%{service} instead of /etc/service) this was done to create a
more appropriate environment for the programs installed.  Compatability
symlinks do exist for /service and /etc directories according to the
author's distribution license.
EOF

echo "gcc %{optflags}" >conf-cc
echo "gcc -s %{optflags}" >conf-ld
echo "%{_prefix}" >conf-home


%build
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}
mkdir -p %{buildroot}

make

# make docs (http://cr.yp.to/slashdoc/slashdoc-merge)
for i in packages commands cfunctions fileformats
do
  sort -f /dev/null `find doc/merge -name $i.html` > doc/$i.new
  mv doc/$i.new doc/$i.html
done


%install

#make setup check
mkdir -p %{buildroot}{%{_sysconfdir},%{_initrddir},%{_bindir}}
install -m 644 dnsroots.global %{buildroot}%{_sysconfdir}

# create dynamic initscript based on service directory
service_dir="`echo %{service}|sed -e 's/\//\\\\\//g'`"
cat %{SOURCE2} | sed -e"s/SERVICE_DIR/$service_dir/g" > %{buildroot}%{_initrddir}/djbdns
chmod 700 %{buildroot}%{_initrddir}/djbdns

for i in axfr-get axfrdns axfrdns-conf dnscache dnscache-conf dnsfilter \
  dnsip dnsipq dnsmx dnsname dnsq dnsqr dnstrace dnstracesort dnstxt pickdns \
  pickdns-conf pickdns-data pickdns-data random-ip rbldns rbldns-conf \
  rbldns-data tinydns tinydns-conf tinydns-data tinydns-edit tinydns-get \
  walldns walldns-conf
do
  install -m 755 $i %{buildroot}%{_bindir}
done
install -m 755 %{SOURCE3} %{buildroot}%{_bindir}

# manpages
mkdir -p %{buildroot}%{_mandir}/man{1,5,8}
install -m644 $RPM_BUILD_DIR/%{name}-%{version}/%{name}-man/*.1 %{buildroot}%{_mandir}/man1
install -m644 $RPM_BUILD_DIR/%{name}-%{version}/%{name}-man/*.5 %{buildroot}%{_mandir}/man5
install -m644 $RPM_BUILD_DIR/%{name}-%{version}/%{name}-man/*.8 %{buildroot}%{_mandir}/man8
cp $RPM_BUILD_DIR/%{name}-%{version}/%{name}-man/README \
  $RPM_BUILD_DIR/%{name}-%{version}/README.manpages
mkdir -p %{buildroot}/var/log/djbdns

# cron job
mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
install -m755 %{SOURCE5} %{buildroot}%{_sysconfdir}/cron.daily/djbdns

# install other extras
install -m755 %{SOURCE6} %{buildroot}%{_bindir}

# create service directories
mkdir -p %{buildroot}%{service}
mkdir -p %{buildroot}/service

# prep for dns caching
mkdir -p %{buildroot}%{djbdir}/{dnscachex,dnscache}
pushd %{buildroot}%{service}
ln -s ../dnscachex dnscachex
ln -s ../dnscache dnscache
cd ../../../service
ln -s ..%{djbdir}/dnscachex dnscachex
ln -s ..%{djbdir}/dnscache dnscache
cd ..%{_sysconfdir}
ln -s ..%{djbdir}/dnscachex dnscachex 
ln -s ..%{djbdir}/dnscache dnscache
popd

# prep for tinydns
mkdir -p %{buildroot}%{djbdir}/tinydns
pushd %{buildroot}%{service}
ln -s ../tinydns tinydns
cd ../../../service
ln -s ..%{djbdir}/tinydns tinydns
cd ..%{_sysconfdir}
ln -s ..%{djbdir}/tinydns tinydns
popd

# prep for axfrdns
mkdir -p %{buildroot}%{djbdir}/axfrdns
pushd %{buildroot}%{service}
ln -s ../axfrdns axfrdns
cd ../../../service
ln -s ..%{djbdir}/axfrdns axfrdns
cd ..%{_sysconfdir}
ln -s ..%{djbdir}/axfrdns axfrdns
popd

# create log symlinks
pushd %{buildroot}/var/log/djbdns
  ln -s ../../..%{djbdir}/dnscachex/log/main dnscachex
  ln -s ../../..%{djbdir}/dnscache/log/main dnscache
  ln -s ../../..%{djbdir}/tinydns/log/main tinydns
  ln -s ../../..%{djbdir}/axfrdns/log/main axfrdns
popd

# devel files
mkdir -p %{buildroot}{%{_includedir}/djbdns,%{_libdir}/djbdns}
cp -av *.h %{buildroot}%{_includedir}/djbdns
cp -av *.a %{buildroot}%{_libdir}/djbdns

%clean
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}-%{version}

%pre
### Before installation
# create groups and users
echo "Creating users and groups for djbdns..."
grep "^djbdns:" %{_sysconfdir}/group >/dev/null || groupadd -r djbdns
grep "^dnslog:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true dnslog
grep "^tinydns:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true tinydns
grep "^axfrdns:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true axfrdns


%pre localcache
### Before installation
# create groups and users
echo "Creating users and groups for djbdns..."
grep "^djbdns:" %{_sysconfdir}/group >/dev/null || groupadd -r djbdns
grep "^dnscache:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true dnscache
grep "^dnslog:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true dnslog

%pre extcache
### Before installation
# create groups and users
echo "Creating users and groups for djbdns..."
grep "^djbdns:" %{_sysconfdir}/group >/dev/null || groupadd -r djbdns
grep "^dnscache:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true dnscache
grep "^dnslog:" %{_sysconfdir}/passwd >/dev/null || useradd -d %{djbdir} -M -r -s /bin/true dnslog

%post
# configuration for full nameserver only if install
if [ $1 = "1" ]; then
  # get IP address for eth0
  HOST=`/sbin/ifconfig eth0|grep 'inet addr'|gawk '{print $2}'|cut -d: -f2`
  # obtain a base (x.x.x)
  BASE=`/sbin/ifconfig eth0|grep 'inet addr'|gawk '{print $2}'|cut -d: -f2|cut -d. -f1,2,3`
  echo "Making some intelligent guesses on tinydns configuration, please check"
  echo "%{djbdir}/tinydns to ensure configuration is correct."
  # tinydns-conf will not work if directory already exists so remove first
  rm -rf %{djbdir}/tinydns
  %{_bindir}/tinydns-conf tinydns dnslog %{djbdir}/tinydns $HOST
  echo ""
  echo "Making some intelligent guesses on axfrdns configuration, please check"
  echo "%{djbdir}/axfrdns to ensure configuration is correct."
  # axfrdns-conf will not work if directory already exists so remove first
  rm -rf %{djbdir}/axfrdns
  %{_bindir}/axfrdns-conf axfrdns dnslog %{djbdir}/axfrdns %{djbdir}/tinydns $HOST
  echo "$BASE.:allow" >>%{djbdir}/axfrdns/tcp
  echo ":allow,AXFR=\"\"" >>%{djbdir}/axfrdns/tcp
  echo ""
  echo "Compiling tcp database for axfrdns..."
  pushd %{djbdir}/axfrdns
    make
  popd
  echo ""
  echo "Please modify %{djbdir}/tinydns/root/Makefile to specify IP address of any"
  echo "secondary DNS servers you wish to replicate data to."
  cat << EOF >%{djbdir}/tinydns/root/Makefile
# Modify the following if you will be replicating to a secondary djbdns server
# and replace [secondary_dns] with the IP address of your secondary djbdns server
#
#remote: data.cdb
#	rsync -az -e ssh data.cdb [secondary_dns]:/var/djbdns/tinydns/root/data.cdb

it: build data.cdb

data.cdb: data
	/usr/bin/tinydns-data
build: zone*
	sort -u zone*|grep -v "#" >data
EOF
  cat << EOF >%{djbdir}/tinydns/root/data
# If this is a secondary djbdns server, data should be copied from the
# primary djbdns server using rsync and ssh and should not be modified on
# this system.  Uncomment the following line to protect data.cdb by stopping
# the make program:
#9
EOF
  echo ""
  echo "Post-install configuration completely.  Many guesses have been made to try to"
  echo "automate the setup as much as possible, however you will still need to"
  echo "fine-tune your configuration.  If you are converting to djbdns from BIND,"
  echo "please visit http://cr.yp.to/djbdns/frombind.html for further instrutions on"
  echo "how to do so."
fi


%_post_service djbdns


%post extcache
# configuration for caching-only nameserver only if install
if [ $1 = "1" ]; then
  # get IP address for eth0
  HOST=`/sbin/ifconfig eth0|grep 'inet addr'|gawk '{print $2}'|cut -d: -f2`
  # obtain a base (x.x.x)
  BASE=`/sbin/ifconfig eth0|grep 'inet addr'|gawk '{print $2}'|cut -d: -f2|cut -d. -f1,2,3`
  echo "Making some intelligent guesses on dnscache configuration, please check"
  echo "%{djbdir}/dnscachex to ensure configuration is correct"
  # dnscache-conf will not work if directory already exists so remove first
  rm -rf %{djbdir}/dnscachex
  %{_bindir}/dnscache-conf dnscache dnslog %{djbdir}/dnscachex $HOST
  touch %{djbdir}/dnscachex/root/ip/$BASE
fi


%_post_service djbdns


%post localcache
# configuration for caching-only nameserver only if install
if [ $1 = "1" ]; then
  # use localhost address
  echo "Making some intelligent guesses on dnscache configuration, please check"
  echo "%{djbdir}/dnscache to ensure configuration is correct"
  # dnscache-conf will not work if directory already exists so remove first
  rm -rf %{djbdir}/dnscache
  %{_bindir}/dnscache-conf dnscache dnslog %{djbdir}/dnscache
fi

/sbin/service djbdns start

%preun
### Before uninstallation
/sbin/service djbdns stop


%preun extcache
### Before uninstallation
/sbin/service djbdns stop

%preun localcache
### Before uninstallation
/sbin/service djbdns stop


%postun
### Post uninstallation
# If djbdns is remove (no upgrade):
if [ $1 = "0" ]; then
  # this is needed for user* and group* programs
  export PATH=$PATH:/usr/sbin

  echo ""
  echo "Removing djbdns users (if they exist):"
  for i in tinydns dnslog dnscache axfrdns; do
    if  id -u $i >/dev/null 2>/dev/null ; then
      echo "  Removing $i user ..."
      userdel $i
    fi
  done

  echo ""
  echo "Removing djbdns group (if it exists):"
  if  groupmod djbdns >/dev/null 2>/dev/null ; then
    echo "  Removing djbdns group ..."
    groupdel djbdns
  fi
fi

%postun extcache
### Post uninstallation
# If djbdns is remove (no upgrade):
if [ $1 = "0" ]; then
  # this is needed for user* and group* programs
  export PATH=$PATH:/usr/sbin

  echo ""
  echo "Removing djbdns users (if they exist):"
  for i in tinydns dnslog dnscache axfrdns ; do
    if  id -u $i >/dev/null 2>/dev/null ; then
      echo "  Removing $i user ..."
      userdel $i
    fi
  done

  echo ""
  echo "Removing djbdns group (if it exists):"
  if  groupmod djbdns >/dev/null 2>/dev/null ; then
    echo "  Removing djbdns group ..."
    groupdel djbdns
  fi
fi

%postun localcache
### Post uninstallation
# If djbdns is remove (no upgrade):
if [ $1 = "0" ]; then
  # only remove users if tinydns doesn't exist (if exists, means full djbdns
  # is installed so don't remove users to break it
  if [ ! -d %{djbdir}/tinydns ]; then
    # this is needed for user* and group* programs
    export PATH=$PATH:/usr/sbin

    echo ""
    echo "Removing djbdns users (if they exist):"
    for i in tinydns dnslog dnscache axfrdns ; do
      if  id -u $i >/dev/null 2>/dev/null ; then
        echo "  Removing $i user ..."
        userdel $i
      fi
    done

    echo ""
    echo "Removing djbdns group (if it exists):"
    if  groupmod djbdns >/dev/null 2>/dev/null ; then
      echo "  Removing djbdns group ..."
      groupdel djbdns
    fi
  fi
fi

%files
%defattr(-,root,root)
%doc doc/*.html README.RPM TINYDNS TODO CHANGES README README.manpages
%config(noreplace) %{_sysconfdir}/dnsroots.global
%config(noreplace) %{_sysconfdir}/cron.daily/djbdns
%{_initrddir}/djbdns
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{djbdir}
%dir %{service}
%attr(1755,root,root) %dir %{djbdir}/tinydns
%{service}/tinydns
/service/tinydns
%attr(1755,root,root) %dir %{djbdir}/axfrdns
%{service}/axfrdns
/service/axfrdns
%dir /var/log/djbdns
/var/log/djbdns/tinydns
/var/log/djbdns/axfrdns
%{_sysconfdir}/tinydns
%{_sysconfdir}/axfrdns


%files extcache
%defattr(-,root,root)
%doc doc/*.html README.RPM  TINYDNS TODO CHANGES README README.manpages
%config(noreplace) %{_sysconfdir}/dnsroots.global
%{_initrddir}/djbdns
%{_bindir}/dnscache
%{_bindir}/dnscache-conf
%{_bindir}/dnsip
%{_bindir}/dnsipq
%{_bindir}/dnsname
%{_bindir}/dnstxt
%{_bindir}/dnsmx
%{_mandir}/man8/dnscache.8*
%{_mandir}/man8/dnscache-conf.8*
%{_mandir}/man1/dnsip.1*
%{_mandir}/man1/dnsipq.1*
%{_mandir}/man1/dnsname.1*
%{_mandir}/man1/dnstxt.1*
%{_mandir}/man1/dnsmx.1*
%dir %{djbdir}
%dir %{service}
%attr(1755,root,root) %dir %{djbdir}/dnscachex
%{service}/dnscachex
/service/dnscachex
%dir /var/log/djbdns
/var/log/djbdns/dnscachex
%{_sysconfdir}/dnscachex


%files localcache
%defattr(-,root,root)
%doc doc/*.html README.RPM  TINYDNS TODO CHANGES README README.manpages
%config(noreplace) %{_sysconfdir}/dnsroots.global
%{_initrddir}/djbdns
%{_bindir}/dnscache
%{_bindir}/dnscache-conf
%{_bindir}/dnsip
%{_bindir}/dnsipq
%{_bindir}/dnsname
%{_bindir}/dnstxt
%{_bindir}/dnsmx
%{_mandir}/man8/dnscache.8*
%{_mandir}/man8/dnscache-conf.8*
%{_mandir}/man1/dnsip.1*
%{_mandir}/man1/dnsipq.1*
%{_mandir}/man1/dnsname.1*
%{_mandir}/man1/dnstxt.1*
%{_mandir}/man1/dnsmx.1*
%dir %{djbdir}
%dir %{service}
%attr(1755,root,root) %dir %{djbdir}/dnscache
%{service}/dnscache
/service/dnscache
%dir /var/log/djbdns
/var/log/djbdns/dnscache
%{_sysconfdir}/dnscache

%files devel
%defattr(-,root,root)
%dir %{_includedir}/djbdns
%{_includedir}/djbdns/*
%dir %{_libdir}/djbdns
%{_libdir}/djbdns/*

%changelog
* Sun Feb 1 2004 Yasuo Ohgaki <yohgaki@momonga-linux.org>
- Momonganize and import

* Mon Mar 17 2003 Vincent Danen <vdanen@mandrakesoft.com> 1.05-19rph
- better build macros (automatically builds for the host OS)

* Sun Mar  9 2003 Paul Cox <paul@coxcentral.com> 1.05-18rph
- Patch0: errno fix for 9.1
- s/Copyright/License/

* Mon Apr 15 2002 Vincent Danen <vdanen@mandrakesoft.com> 1.05-17rph
- 9.0 support
- add --with 8x to build for 8.x (builds for 9.0 by default)
- don't force a uid/gid number anymore; let the system assign it itself
- include RPMOPTIONS in README.RPM

* Mon Apr 15 2002 Vincent Danen <vdanen@mandrakesoft.com> 1.05-16rph
- rebuild with rph extension

* Mon Jan 14 2002 Vincent Danen <vdanen@mandrakesoft.com> 1.05-15mdk
- daemontools now includes /service, so we'll put symlinks in /service
  anyways (%%rootsrv is still useful if you want to change service location
  in the initscript)
- compatability in /etc (ugly, but we have to do it for the license)
- use %%_post_service and %%_preun_service if not %%build_72
- use /var/lock/subsys in initscript
- fix empty %%pre on non-7.2 builds

* Wed Dec 19 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-14mdk
- s/expend/expand/ (re: Oden Eriksson)
- add "it" to tinydns Makefile (now just "make it") (re: Oden Eriksson)

* Mon Nov 26 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-13mdk
- use --with 7.2 to build for 7.2; otherwise we build for 8.0+ which
  includes the required djbdns users
- use --with rootservice to use /service instead of /var/djbdns/service

* Fri Jun 20 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-12mdk
- rebuild for 8.0

* Sun Apr 29 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-11mdk
- fix initscript to use proper service directory

* Thu Apr 12 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-10mdk
- revamp package to provide local and external dnscache; external conflicts
  with full djbdns while local can co-exist with full djbdns
- on uninstall of djbdns-localcache, do not remove users if full djbdns is
  installed
- extcache uses dnscachex, localcache uses dnscache
- modified README.RPM
- djbdns-extcache and djbdns-localcache both obsolete djbdns-cache
- make sure all instance of /var/djbdns is replaced by %%{djbdir}
- because djbdns-cache is obsolete, you must first remove it (rpm -e) prior
  to installing extcache or localcache (otherwise the upgrade will seriously
  break (sorry about that, no real way around it))

* Thu Apr 12 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-9mdk
- fixes from Thomas Mangin <systems-thomas@legend.co.uk>:
  - fix typeo that resulted in damaged symlink
- suggestion from Thomas Mangin <systems-thomas@legend.co.uk>:
  - make initscript dynamic so rebuild with different service location does
    not require user to make manual changes to initscript

* Wed Apr 11 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-8mdk
- fix permissions on /var/djbdns/{tinydns,axfrdns,dnscachex}, force mode
  1755 so upgrades don't break logging

* Wed Apr 11 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-7mdk
- suggestion from Thomas Mangin <systems-thomas@legend.co.uk>:
  - make a define for location of the service directory (/service or
    /var/djbdns/service) so you can choose for rebuild (default is still
    /var/djbdns/service) 

* Sun Mar 25 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-6mdk
- modified %{djbdir}/tinydns/root/Makefile to not include comments (#) into
  the data file
- add daily cronjob
- include Kenji Rikitake's tinydns-log.pl, a logfile formatter for tinydns

* Sun Mar 25 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-5mdk
- fix initscript
- fix problem with uninstall scripts.  Users upgrading from 1.05-4mdk will
  need to remove djbdns-1.05-4mdk using the --noscripts command switch

* Wed Mar 14 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-4mdk
- don't turn djbdns off with chkconfig if upgrading
- create default %{djbdir}/tinydns/root/data file with instructions for
  secondary djbdns servers
- create djbdns-getdata which is used to obtain DNS info from BIND servers
  (useful when converting from BIND to djbdns)
- add build command to %{djbdir}/tinydns/root/Makefile so you can keep
  zone files in seperate files (ala BIND), but build them into the single
  data file djbdns needs (use: make build; make)
- added manpages from ftp.innominate.org

* Sun Mar 11 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-3mdk
- added devel package

* Sun Mar 11 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-2mdk
- the *-conf files will not operate if target directory exists, so remove
  the directory first, then run *-conf (not nice but necessary)
- run *-conf only on install, not upgrades
- add %%postun scripts to remove users/groups on uninstall
- fix symlinks
- make better test to see if djbdns is running on uninstall (prevent ugly
  error messages)
- include some of the DNS lookup tools in the djbdns-cache package
- update initscript to remove pid file on stop

* Sat Mar 10 2001 Vincent Danen <vdanen@mandrakesoft.com> 1.05-1mdk
- first mandrake adaptation
- create initscript for djbdns
- create package for caching-only nameserver
- try to intelligently configure dnscache or tinydns and axfrdns (depending
  on the package installed)
- create symlinks for log files so they can all be reached under
  /var/log/djbdns instead of all over the place
